/** 
 * @file   TBCom.h
 * @author Bernd Ottmann
 * @date   20.04.2005
 * @brief  Deklarationen der Exportroutinen.
 * @note   Die Auflistung der Routinen ist wie in der zugehoerigen Dokumentation.
 */
//////////////////////////////////////////////////////////////////////
#ifndef _TBCOM_H_
#define _TBCOM_H_

/** 
 @mainpage Dokumentation zur TBCom.
 <center> @code 

   ########################################################
   ##       |                   |                  |     ##
   ##                          \_/                       ##
   ##       |                 -(_)-                |  \  ##
   ##                          / \                    |\\##
   ##  /|   |                                      |  || ##
   ##/ ||                  _\|||/_                    || ##
   ##  ||   |               /_=_\                  |  || ##
   ##  ||                  ({}-{})                    || ##
   ##  ||   |+-----oOo-------(_)---------------+   |  || ##
   ## //     |                                 |      || ##
   ##/      ||          Datafox GmbH           |   |  || ##
   ##        |                                 |      || ##
   ##       |+-------------------------oOo-----+   |  || ##
   ##                     |  |~|  |                   || ##
   ##       |_ __ _ __ _ _|__| |__|_ __ _ __ _ __ _|  || ##
   ##      /               ||   ||                  \ || ##
   ##    /               .ooO   Ooo.                  \ \##
   ##  /                                                \##
   ########################################################

 @endcode </center>
 @author Bernd Ottmann
 @date   20.04.2005
*/

// ########################################################
// ###################### DEFINES #########################
// ########################################################

/**
 * Version der verwendeten DLL.
 * 
 * @todo Version der verwendeten DLL pruefen, um nur die enthaltenen Routinen zu 
 * importieren oder auch zu exportieren.
 */
// Benutzung ab Version 1.2
//#define COM_VERSION          1
//#define COM_VERSION          0x01030000
//#define COM_VERSION          0x01070000
//#define COM_VERSION          0x01080000
//#define COM_VERSION          0x01090000
//#define COM_VERSION          0x01100000
//#define COM_VERSION          0x01110000
//#define COM_VERSION          0x01120000
//#define COM_VERSION          0x01150000
//#define COM_VERSION          0x01160000
//#define COM_VERSION          0x01190000
//#define COM_VERSION          0x01260000
#define COM_VERSION          0x01280000

/**
 * Gibt export oder import der Routinen an. Siehe auch EXTERN_DECL.
 *
 * @todo Mit 1 im Quelltext vor #include zu definieren um die Routinen als Import zu erhalten.
 *
 * @code #define AE3COM_EXPORT   1 @endcode
 */
#ifndef AE3COM_EXPORT
	#define AE3COM_EXPORT 0
#endif

#ifndef USE_PRIVATE
	#define USE_PRIVATE   0
#endif

// Eventuell fehlende typedefs ersetzen
#ifdef _WIN32

#ifndef HANDLE
	#define HANDLE void*
#endif

#endif
// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// +------------+ EXPORTIERTE FUNKTIONEN +----------------+
// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++

/**
 @def EXTERN_DECL Gibt den Praefix fuer Funktionen an. (Dekorierung und Export-, Importangabe)
*/

#ifdef _WIN32

#if (AE3COM_EXPORT)
	// Einzubindende Bibliotheken: Version.lib, WSock32.lib
	#define EXTERN_DECL         extern "C" __declspec(dllexport)
	// DllGetVersion
	#include "shlwapi.h"
#else
	#define EXTERN_DECL         extern "C" __declspec(dllimport)
#endif

#else

#define EXTERN_DECL             extern "C"
#define __declspec(dllexport)
#define __stdcall

#endif


// ########################################################
// ############## ALLGEMEINE FUNKTIONEN ###################
// ########################################################

EXTERN_DECL int __stdcall TBCComInit(int ComNum);

#if (COM_VERSION >= 0x01150000)
EXTERN_DECL int __stdcall TBCComInit38400(int ComNum);
#endif

EXTERN_DECL int __stdcall TBCSerialOpen(char *ComPort, int BaudRate, int TimeOut, int Radio);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCSerialOpenExt(int ChannelNum, char *ComPort, int BaudRate, int TimeOut, int Radio);
#endif

EXTERN_DECL int __stdcall TBCComOpen(char *remoteIP);

EXTERN_DECL int __stdcall TBCSocketOpen(char *RemoteIP, int PortNo, int TimeOut, int Radio);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCSocketOpenExt(int ChannelNum, char *RemoteIP, int PortNo, int TimeOut, int Radio);
#endif

EXTERN_DECL HANDLE __stdcall TBCGetComPort(void);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL HANDLE __stdcall TBCGetComPortExt(int ChannelNum);
#endif

EXTERN_DECL int __stdcall TBCSetComPort(HANDLE ComPort, int PortIsSocket, int BaudRate, int TimeOut, int Radio);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCSetComPortExt(int ChannelNum, HANDLE ComPort, int PortIsSocket, int BaudRate, int TimeOut, int Radio);
#endif

EXTERN_DECL void __stdcall TBCComClose(void);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL void __stdcall TBCComCloseExt(int ChannelNum);
#endif

#if (COM_VERSION >= 0x01110000)
EXTERN_DECL void __stdcall TBCSetCallBack(int (*CBFunction)());
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL void __stdcall TBCSetCallBackExt(int ChannelNum, int (*CBFunction)());
#endif
#endif

EXTERN_DECL unsigned long __stdcall TBCBinToULongMSBFirst(unsigned char *Buf);

#if (COM_VERSION >= 0x01120000)
EXTERN_DECL void __stdcall TBCSetFunkOn();
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL void __stdcall TBCSetFunkOnExt(int ChannelNum);
#endif
EXTERN_DECL void __stdcall TBCSetFunkOff();
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL void __stdcall TBCSetFunkOffExt(int ChannelNum);
#endif
#endif

#if (COM_VERSION >= 0x01160000)
EXTERN_DECL void __stdcall TBCNurTbIIOn();
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL void __stdcall TBCNurTbIIOnExt(int ChannelNum);
#endif
EXTERN_DECL void __stdcall TBCNurTbIIOff();
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL void __stdcall TBCNurTbIIOffExt(int ChannelNum);
#endif
#endif

EXTERN_DECL void __stdcall TBCSetComCheckBeginEndOn();

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL void __stdcall TBCSetComCheckBeginEndOnExt(int ChannelNum);
#endif

EXTERN_DECL void __stdcall TBCSetComCheckBeginEndOff();

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL void __stdcall TBCSetComCheckBeginEndOffExt(int ChannelNum);
#endif

EXTERN_DECL int __stdcall TBCCheckDevice(int BusNum, int *Error, int DockingPollRetry, int DevicePollRetry);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCCheckDeviceExt(int ChannelNum, int BusNum, int *Error, int DockingPollRetry, int DevicePollRetry);
#endif

#if (COM_VERSION >= 0x01090000)
EXTERN_DECL int __stdcall TBCCheckTB(int BusNum, int *Error);
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCCheckTBExt(int ChannelNum, int BusNum, int *Error);
#endif
#endif

EXTERN_DECL void __stdcall TBCGetDevicePollRetry(int *DockingPollRetry, int *DevicePollRetry);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL void __stdcall TBCGetDevicePollRetryExt(int ChannelNum, int *DockingPollRetry, int *DevicePollRetry);
#endif

EXTERN_DECL int __stdcall TBCBeginCom(unsigned char BusNum, int *Error);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCBeginComExt(int ChannelNum, unsigned char BusNum, int *Error);
#endif

EXTERN_DECL int __stdcall TBCEndCom(unsigned char BusNum, int *Error);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCEndComExt(int ChannelNum, unsigned char BusNum, int *Error);
#endif

#if (COM_VERSION >= 0x01030000)
EXTERN_DECL void __stdcall TBCSetPasswort(unsigned char *Pass);
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL void __stdcall TBCSetPasswortExt(int ChannelNum, unsigned char *Pass);
#endif
#endif

EXTERN_DECL int __stdcall TBCGetPassword(int BusNum,  int *Error, unsigned char *Password);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCGetPasswordExt(int ChannelNum, int BusNum,  int *Error, unsigned char *Password);
#endif

#if (COM_VERSION >= 0x01110000)
EXTERN_DECL int __stdcall TBCGetSeriennummer(int BusNum, int *Error, int *SerNum);
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCGetSeriennummerExt(int ChannelNum, int BusNum, int *Error, int *SerNum);
#endif
#endif

EXTERN_DECL int __stdcall TBCSetDateTime(int BusNum, int *Error, unsigned char *Buf);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCSetDateTimeExt(int ChannelNum, int BusNum, int *Error, unsigned char *Buf);
#endif

#if (COM_VERSION >= 0x01090000)
EXTERN_DECL int __stdcall TBCGetDateTime(int BusNum, int *Error, unsigned char *Buf);
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCGetDateTimeExt(int ChannelNum, int BusNum, int *Error, unsigned char *Buf);
#endif
#endif

#if (COM_VERSION >= 0x01070000)
EXTERN_DECL int __stdcall TBCAus(int BusNum, int *Error);
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCAusExt(int ChannelNum, int BusNum, int *Error);
#endif
#endif

EXTERN_DECL int __stdcall TBCSetMessage(int BusNum, int *Error, unsigned char *Message, int MessageIsFormatted, int SendLineByLine);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCSetMessageExt(int ChannelNum, int BusNum, int *Error, unsigned char *Message, int MessageIsFormatted, int SendLineByLine);
#endif

#if (COM_VERSION >= 0x01080000)
EXTERN_DECL int __stdcall TBCMessage(int BusNum, unsigned char *Message, int *Error);
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCMessageExt(int ChannelNum, int BusNum, unsigned char *Message, int *Error);
#endif
#endif

#if (COM_VERSION >= 0x01080000)
EXTERN_DECL int __stdcall TBCSetGlobVar(int BusNum, unsigned char *GlobVarS1,unsigned char *GlobVarS2, unsigned char *GlobVarS3,unsigned char *GlobVarS4, unsigned int GlobVarI1,unsigned int GlobVarI2, unsigned int GlobVarI3,unsigned int GlobVarI4, int *Error);
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCSetGlobVarExt(int ChannelNum, int BusNum, unsigned char *GlobVarS1,unsigned char *GlobVarS2, unsigned char *GlobVarS3,unsigned char *GlobVarS4, unsigned int GlobVarI1,unsigned int GlobVarI2, unsigned int GlobVarI3,unsigned int GlobVarI4, int *Error);
#endif
#endif

EXTERN_DECL void __stdcall TBCSetLogFileName(const unsigned char *LogFileName);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL void __stdcall TBCSetLogFileNameExt(int ChannelNum, const unsigned char *LogFileName);
#endif

EXTERN_DECL void __stdcall TBCSetLogOn();

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL void __stdcall TBCSetLogOnExt(int ChannelNum);
#endif

EXTERN_DECL void __stdcall TBCSetLogOff();

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL void __stdcall TBCSetLogOffExt(int ChannelNum);
#endif

EXTERN_DECL void __stdcall TBCGetErrorText(int ErrNo, char *Text, int Length);

#if (COM_VERSION >= 0x01190000)
EXTERN_DECL int __stdcall TBCGetGlobVar(int BusNum, unsigned char *GlobVarS1,unsigned char *GlobVarS2, unsigned char *GlobVarS3,unsigned char *GlobVarS4, unsigned int *GlobVarI1,unsigned int *GlobVarI2, unsigned int *GlobVarI3,unsigned int *GlobVarI4, int *Error);
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCGetGlobVarExt(int ChannelNum, int BusNum, unsigned char *GlobVarS1,unsigned char *GlobVarS2, unsigned char *GlobVarS3,unsigned char *GlobVarS4, unsigned int *GlobVarI1,unsigned int *GlobVarI2, unsigned int *GlobVarI3,unsigned int *GlobVarI4, int *Error);
#endif
#endif

#if (COM_VERSION >= 0x01280000)
EXTERN_DECL int __stdcall TBCWriteExt(int ChannelNum, char *Buf, int Length, int *WriteLength, int *Error);
EXTERN_DECL int __stdcall TBCReadExt(int ChannelNum, char *Buf, int Length, int *ReadLength, int *Error);
#endif


// ########################################################
// ############## FUNKTIONEN FUER SETUP ###################
// ########################################################

EXTERN_DECL int __stdcall TBCSetupLaden(int BusNum, char *DateiName, int *Error);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCSetupLadenExt(int ChannelNum, int BusNum, char *DateiName, int *Error);
#endif


// ########################################################
// ############## FUNKTIONEN FUER DATEN ###################
// ########################################################

EXTERN_DECL int __stdcall TBCLoadDaten(int BusNum, int *Error);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCLoadDatenExt(int ChannelNum, int BusNum, int *Error);
#endif

EXTERN_DECL int __stdcall TBCClrDaten(int BusNum, int *Error);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCClrDatenExt(int ChannelNum, int BusNum, int *Error);
#endif

#if (COM_VERSION >= 0x01120000)
EXTERN_DECL int __stdcall TBCLoadDatensatzOnline(int BusNum, int *Error, int *DatLen, int *DatBeschreibungNum, unsigned char *Buf);
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCLoadDatensatzOnlineExt(int ChannelNum, int BusNum, int *Error, int *DatLen, int *DatBeschreibungNum, unsigned char *Buf);
#endif

EXTERN_DECL int __stdcall TBCClrDatensatzOnline(int BusNum, int *Error);
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCClrDatensatzOnlineExt(int ChannelNum, int BusNum, int *Error);
#endif
#endif

EXTERN_DECL int __stdcall TBCDatCnt(void);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCDatCntExt(int ChannelNum);
#endif

EXTERN_DECL int __stdcall TBCDatBeschreibungNum(int DatNum);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCDatBeschreibungNumExt(int ChannelNum, int DatNum);
#endif

EXTERN_DECL int __stdcall TBCDatLen(int DatNum);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCDatLenExt(int ChannelNum, int DatNum);
#endif

EXTERN_DECL int __stdcall TBCDatCopy(int DatNum, unsigned char *Buf);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCDatCopyExt(int ChannelNum, int DatNum, unsigned char *Buf);
#endif

#if (COM_VERSION >= 0x01100000)
EXTERN_DECL int __stdcall TBCLoadDatensatzbeschreibung(int BusNum, int *Error);
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCLoadDatensatzbeschreibungExt(int ChannelNum, int BusNum, int *Error);
#endif

EXTERN_DECL int __stdcall TBCDatBCnt(void);
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCDatBCntExt(int ChannelNum);
#endif

EXTERN_DECL int __stdcall TBCDatBDatensatz(int DatBeschreibungNum, unsigned char *Name, int *Felder);
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCDatBDatensatzExt(int ChannelNum, int DatBeschreibungNum, unsigned char *Name, int *Felder);
#endif

EXTERN_DECL int __stdcall TBCDatBFeld(int DatBeschreibungNum, int Feld, unsigned char *Name, int *Typ, int *Len);
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCDatBFeldExt(int ChannelNum, int DatBeschreibungNum, int Feld, unsigned char *Name, int *Typ, int *Len);
#endif
#endif


// ########################################################
// ############## FUNKTIONEN FUER LISTEN ##################
// ########################################################


EXTERN_DECL int __stdcall TBCMakeListe(int ListNum, int ListCnt, int ListSize, unsigned char *Buf, int ListMemSizeNum);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCMakeListeExt(int ChannelNum, int ListNum, int ListCnt, int ListSize, unsigned char *Buf, int ListMemSizeNum);
#endif

EXTERN_DECL int __stdcall TBCLoadListen(int BusNum, int *Error);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCLoadListenExt(int ChannelNum, int BusNum, int *Error);
#endif

EXTERN_DECL void __stdcall TBCClrListenBuffer(void);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL void __stdcall TBCClrListenBufferExt(int ChannelNum);
#endif

EXTERN_DECL int __stdcall TBCMakeListeVF(int ListNum, int ListCnt, int ListSize, unsigned char *Buf, int ListMemSizeNum, int ListMemSizeNumV, int VarListe);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCMakeListeVFExt(int ChannelNum, int ListNum, int ListCnt, int ListSize, unsigned char *Buf, int ListMemSizeNum, int ListMemSizeNumV, int VarListe);
#endif

EXTERN_DECL int __stdcall TBCLoadListenVF(int BusNum, int *Error, int NurVarListen);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCLoadListenVFExt(int ChannelNum, int BusNum, int *Error, int NurVarListen);
#endif

EXTERN_DECL void __stdcall TBCClrListenBufferVF(void);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL void __stdcall TBCClrListenBufferVFExt(int ChannelNum);
#endif

#if (COM_VERSION >= 0x01100000)
EXTERN_DECL int __stdcall TBCLoadListenbeschreibung(int BusNum, int *Error);
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCLoadListenbeschreibungExt(int ChannelNum, int BusNum, int *Error);
#endif

EXTERN_DECL int __stdcall TBCListBCnt(void);
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCListBCntExt(int ChannelNum);
#endif

EXTERN_DECL int __stdcall TBCListBDatensatz(int ListBeschreibungNum, unsigned char *Name, int *Felder, int *VarList);
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCListBDatensatzExt(int ChannelNum, int ListBeschreibungNum, unsigned char *Name, int *Felder, int *VarList);
#endif

EXTERN_DECL int __stdcall TBCListBFeld(int ListBeschreibungNum, int Feld, unsigned char *Name, int *Typ, int *Len);
#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCListBFeldExt(int ChannelNum, int ListBeschreibungNum, int Feld, unsigned char *Name, int *Typ, int *Len);
#endif
#endif

EXTERN_DECL int __stdcall TBCListSizeNum(void);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCListSizeNumExt(int ChannelNum);
#endif

EXTERN_DECL int __stdcall TBCListSizeNumV(void);

#if (COM_VERSION >= 0x01260000)
EXTERN_DECL int __stdcall TBCListSizeNumVExt(int ChannelNum);
#endif


// ########################################################
// ############# ** PRIVATE FUNKTIONEN ** #################
// ########################################################

// Funktionen sind nicht dokumentiert.
// Sie werden von AESetup oder Talk verwendet.
// Unterliegen evntl. Aenderungen.

#if (USE_PRIVATE)


#endif // USE_PRIVATE

#endif


